@@ -16,29 +16,8 @@ from functools import partial
 from typing import Any, Callable, List, Optional, Union
 
 import pandas as pd
-from pytorch_lightning.utilities import rank_zero_warn
 
 from flash.core.data.utilities.paths import PATH_TYPE
-from flash.core.utilities.imports import _PANDAS_GREATER_EQUAL_1_3_0
-
-
-def read_csv(file: PATH_TYPE) -> pd.DataFrame:
-    """A wrapper for ``pd.read_csv`` which tries to handle errors gracefully.
-
-    Args:
-        file: The CSV file to read.
-
-    Returns:
-        A ``DataFrame`` containing the contents of the file.
-    """
-    try:
-        return pd.read_csv(file, encoding="utf-8")
-    except UnicodeDecodeError:
-        rank_zero_warn("A UnicodeDecodeError was raised when reading the CSV. This error will be ignored.")
-        if _PANDAS_GREATER_EQUAL_1_3_0:
-            return pd.read_csv(file, encoding="utf-8", encoding_errors="ignore")
-        else:
-            return pd.read_csv(file, encoding=None, engine="python")
 
 
 def _resolve_multi_target(target_keys: List[str], row: pd.Series) -> List[Any]:
