@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Callable, Dict, Mapping, Sequence, Type, Union
+from typing import Callable, Dict, Mapping, Sequence, Union
 
 from torch import nn
 
@@ -29,13 +29,3 @@ def get_callable_dict(fn: Union[nn.Module, Callable, Mapping, Sequence]) -> Unio
         return {get_callable_name(f): f for f in fn}
     if callable(fn):
         return {get_callable_name(fn): fn}
-
-
-def _is_overridden(method_name: str, instance: object, parent: Type[object]) -> bool:
-    """Cropped Version of https://github.com/Lightning-
-    AI/lightning/blob/master/src/pytorch_lightning/utilities/model_helpers.py."""
-
-    if not hasattr(instance, method_name):
-        return False
-
-    return getattr(instance, method_name).__code__ != getattr(parent, method_name).__code__
