@@ -17,7 +17,6 @@ from pytorch_lightning.core.datamodule import LightningDataModule
 from pytorch_lightning.core.lightning import LightningModule
 from pytorch_lightning.trainer.trainer import Trainer
 from pytorch_lightning.utilities.cloud_io import get_filesystem
-from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.model_helpers import is_overridden
 from pytorch_lightning.utilities.seed import seed_everything
 from torch.optim import Optimizer
@@ -110,7 +109,7 @@ class LightningArgumentParser(ArgumentParser):
                 fail_untyped=False,
                 instantiate=not issubclass(cast(type, lightning_class), Trainer),
             )
-        raise MisconfigurationException(
+        raise TypeError(
             f"Cannot add arguments from: {lightning_class}. You should provide either a callable or a subclass of: "
             "Trainer, LightningModule, LightningDataModule, or Callback."
         )
@@ -413,7 +412,7 @@ class LightningCLI:
             return
 
         if len(optimizers) > 1 or len(lr_schedulers) > 1:
-            raise MisconfigurationException(
+            raise ValueError(
                 f"`{self.__class__.__name__}.add_configure_optimizers_method_to_model` expects at most one optimizer "
                 f"and one lr_scheduler to be 'AUTOMATIC', but found {optimizers+lr_schedulers}. In this case the user "
                 "is expected to link the argument groups and implement `configure_optimizers`, see "
