@@ -17,7 +17,7 @@ from typing import Callable, Optional, Sequence
 import torch.nn as nn
 
 from flash.core.registry import FlashRegistry
-from flash.image.embedding.vissl.transforms import moco_collate_fn, multicrop_collate_fn, simclr_collate_fn
+from flash.image.embedding.vissl.transforms import multicrop_collate_fn, simclr_collate_fn
 from flash.image.embedding.vissl.transforms.multicrop import StandardMultiCropSSLTransform
 
 
@@ -31,7 +31,7 @@ def simclr_transform(
     normalize: Optional[nn.Module] = None,
     collate_fn: Callable = simclr_collate_fn,
 ) -> partial:
-    """For simclr, barlow twins and moco."""
+    """For simclr and barlow twins."""
     transform = partial(
         StandardMultiCropSSLTransform,
         total_num_crops=total_num_crops,
@@ -57,7 +57,7 @@ def swav_transform(
     normalize: Optional[nn.Module] = None,
     collate_fn: Callable = multicrop_collate_fn,
 ) -> partial:
-    """For swav and dino."""
+    """For swav."""
     transform = partial(
         StandardMultiCropSSLTransform,
         total_num_crops=total_num_crops,
@@ -74,16 +74,12 @@ def swav_transform(
 
 
 barlow_twins_transform = partial(simclr_transform, collate_fn=simclr_collate_fn)
-moco_transform = partial(simclr_transform, collate_fn=moco_collate_fn)
-dino_transform = partial(swav_transform, total_num_crops=10, num_crops=[2, 8], collate_fn=multicrop_collate_fn)
 
 
 transforms = [
     "simclr_transform",
     "swav_transform",
     "barlow_twins_transform",
-    "moco_transform",
-    "dino_transform",
 ]
 
 
@@ -93,8 +89,6 @@ def register_vissl_transforms(register: FlashRegistry):
             simclr_transform,
             swav_transform,
             barlow_twins_transform,
-            moco_transform,
-            dino_transform,
         )
     ):
         register(transform, name=transforms[idx])
