@@ -1,7 +1,3 @@
 from flash.core.utilities.imports import _VISSL_AVAILABLE  # noqa: F401
 from flash.image.embedding.vissl.transforms.multicrop import StandardMultiCropSSLTransform  # noqa: F401
-from flash.image.embedding.vissl.transforms.utilities import (  # noqa: F401
-    moco_collate_fn,
-    multicrop_collate_fn,
-    simclr_collate_fn,
-)
+from flash.image.embedding.vissl.transforms.utilities import multicrop_collate_fn, simclr_collate_fn  # noqa: F401
