@@ -14,13 +14,20 @@
 from functools import partial
 from typing import Any, Callable, Dict, List, Optional, Type, Union
 
+from torch import tensor
+
 from flash.core.data.data_module import DataModule
 from flash.core.data.io.input import DataKeys, Input
 from flash.core.data.io.output_transform import OutputTransform
 from flash.core.data.utilities.sort import sorted_alphanumeric
 from flash.core.integrations.icevision.data import IceVisionInput
 from flash.core.integrations.icevision.transforms import IceVisionInputTransform
-from flash.core.utilities.imports import _ICEVISION_AVAILABLE
+from flash.core.utilities.imports import (
+    _ICEVISION_AVAILABLE,
+    _IMAGE_EXTRAS_TESTING,
+    _TORCHVISION_AVAILABLE,
+    _TORCHVISION_GREATER_EQUAL_0_9,
+)
 from flash.core.utilities.stages import RunningStage
 from flash.core.utilities.types import INPUT_TRANSFORM_TYPE
 
@@ -32,16 +39,27 @@ else:
     VOCMaskParser = object
     Parser = object
 
+if _TORCHVISION_AVAILABLE:
+    from torchvision import transforms as T
+
+    if _TORCHVISION_GREATER_EQUAL_0_9:
+        from torchvision.transforms import InterpolationMode
+    else:
+
+        class InterpolationMode:
+            NEAREST = "nearest"
+
 
 # Skip doctests if requirements aren't available
-if not _ICEVISION_AVAILABLE:
+if not _IMAGE_EXTRAS_TESTING:
     __doctest_skip__ = ["InstanceSegmentationData", "InstanceSegmentationData.*"]
 
 
 class InstanceSegmentationOutputTransform(OutputTransform):
-    @staticmethod
-    def uncollate(batch: Any) -> Any:
-        return batch[DataKeys.PREDS]
+    def per_sample_transform(self, sample: Any) -> Any:
+        resize = T.Resize(sample[DataKeys.METADATA]["size"], interpolation=InterpolationMode.NEAREST)
+        sample[DataKeys.PREDS]["masks"] = [resize(tensor(mask)) for mask in sample[DataKeys.PREDS]["masks"]]
+        return sample[DataKeys.PREDS]
 
 
 class InstanceSegmentationData(DataModule):
@@ -62,17 +80,14 @@ class InstanceSegmentationData(DataModule):
         test_ann_file: Optional[str] = None,
         test_parser_kwargs: Optional[Dict[str, Any]] = None,
         predict_folder: Optional[str] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         parser: Optional[Union[Callable, Type[Parser]]] = None,
         input_cls: Type[Input] = IceVisionInput,
+        transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         transform_kwargs: Optional[Dict] = None,
         **data_module_kwargs,
     ) -> "InstanceSegmentationData":
 
-        ds_kw = dict(parser=parser, transform_kwargs=transform_kwargs)
+        ds_kw = dict(parser=parser)
 
         return cls(
             input_cls(
@@ -80,7 +95,6 @@ class InstanceSegmentationData(DataModule):
                 train_folder,
                 train_ann_file,
                 parser_kwargs=train_parser_kwargs,
-                transform=train_transform,
                 **ds_kw,
             ),
             input_cls(
@@ -88,7 +102,6 @@ class InstanceSegmentationData(DataModule):
                 val_folder,
                 val_ann_file,
                 parser_kwargs=val_parser_kwargs,
-                transform=val_transform,
                 **ds_kw,
             ),
             input_cls(
@@ -96,10 +109,11 @@ class InstanceSegmentationData(DataModule):
                 test_folder,
                 test_ann_file,
                 parser_kwargs=test_parser_kwargs,
-                transform=test_transform,
                 **ds_kw,
             ),
-            input_cls(RunningStage.PREDICTING, predict_folder, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_folder, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -113,11 +127,8 @@ class InstanceSegmentationData(DataModule):
         test_folder: Optional[str] = None,
         test_ann_file: Optional[str] = None,
         predict_folder: Optional[str] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         input_cls: Type[Input] = IceVisionInput,
+        transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         transform_kwargs: Optional[Dict] = None,
         **data_module_kwargs: Any,
     ):
@@ -138,12 +149,8 @@ class InstanceSegmentationData(DataModule):
             test_folder: The folder containing images to use when testing.
             test_ann_file: The COCO format annotation file to use when testing.
             predict_folder: The folder containing images to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-              predicting.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
               :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -252,13 +259,10 @@ class InstanceSegmentationData(DataModule):
             test_folder=test_folder,
             test_ann_file=test_ann_file,
             predict_folder=predict_folder,
-            train_transform=train_transform,
-            val_transform=val_transform,
-            test_transform=test_transform,
-            predict_transform=predict_transform,
-            transform_kwargs=transform_kwargs,
             parser=COCOMaskParser,
             input_cls=input_cls,
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -276,11 +280,8 @@ class InstanceSegmentationData(DataModule):
         test_target_folder: Optional[str] = None,
         test_ann_folder: Optional[str] = None,
         predict_folder: Optional[str] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         input_cls: Type[Input] = IceVisionInput,
+        transform: INPUT_TRANSFORM_TYPE = IceVisionInputTransform,
         transform_kwargs: Optional[Dict] = None,
         **data_module_kwargs: Any,
     ):
@@ -307,12 +308,8 @@ class InstanceSegmentationData(DataModule):
             test_target_folder: The folder containing mask images to use when testing.
             test_ann_folder: The folder containing VOC format annotation files to use when testing.
             predict_folder: The folder containing images to use when predicting.
-            train_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when training.
-            val_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when validating.
-            test_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when testing.
-            predict_transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use when
-              predicting.
             input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
             transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
             data_module_kwargs: Additional keyword arguments to provide to the
               :class:`~flash.core.data.data_module.DataModule` constructor.
@@ -444,13 +441,10 @@ class InstanceSegmentationData(DataModule):
             test_ann_file=test_ann_folder,
             test_parser_kwargs={"masks_dir": test_target_folder},
             predict_folder=predict_folder,
-            train_transform=train_transform,
-            val_transform=val_transform,
-            test_transform=test_transform,
-            predict_transform=predict_transform,
-            transform_kwargs=transform_kwargs,
             parser=partial(VOCMaskParser, class_map=ClassMap(list(sorted_alphanumeric(labels)))),
             input_cls=input_cls,
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -477,10 +471,10 @@ class InstanceSegmentationData(DataModule):
         Returns:
             The constructed data module.
         """
-        ds_kw = dict(transform=predict_transform, transform_kwargs=transform_kwargs)
-
         return cls(
-            predict_input=input_cls(RunningStage.PREDICTING, predict_folder, **ds_kw),
+            predict_input=input_cls(RunningStage.PREDICTING, predict_folder),
+            transform=predict_transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -507,9 +501,9 @@ class InstanceSegmentationData(DataModule):
         Returns:
             The constructed data module.
         """
-        ds_kw = dict(transform=predict_transform, transform_kwargs=transform_kwargs)
-
         return cls(
-            predict_input=input_cls(RunningStage.PREDICTING, predict_files, **ds_kw),
+            predict_input=input_cls(RunningStage.PREDICTING, predict_files),
+            transform=predict_transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
