@@ -24,7 +24,7 @@ __all__ = ["style_transfer"]
 def from_coco_128(
     batch_size: int = 4,
     num_workers: int = 0,
-    **preprocess_kwargs,
+    **data_module_kwargs,
 ) -> StyleTransferData:
     """Downloads and loads the COCO 128 data set."""
     download_data("https://github.com/zhiqwang/yolov5-rt-stack/releases/download/v0.3.0/coco128.zip", "data/")
@@ -32,7 +32,7 @@ def from_coco_128(
         train_folder="data/coco128/images/train2017/",
         batch_size=batch_size,
         num_workers=num_workers,
-        **preprocess_kwargs,
+        **data_module_kwargs,
     )
 
 
