@@ -23,10 +23,14 @@ from flash.core.data.io.output import Output
 from flash.core.integrations.pytorch_tabular.backbones import PYTORCH_TABULAR_BACKBONES
 from flash.core.registry import FlashRegistry
 from flash.core.serve import Composition
-from flash.core.utilities.imports import requires
+from flash.core.utilities.imports import _TABULAR_TESTING, requires
 from flash.core.utilities.types import INPUT_TRANSFORM_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE
 from flash.tabular.input import TabularDeserializer
 
+# Skip doctests if requirements aren't available
+if not _TABULAR_TESTING:
+    __doctest_skip__ = ["TabularClassifier", "TabularClassifier.*"]
+
 
 class TabularClassifier(ClassificationAdapterTask):
     """The ``TabularClassifier`` is a :class:`~flash.Task` for classifying tabular data. For more details, see
@@ -72,7 +76,7 @@ class TabularClassifier(ClassificationAdapterTask):
     ):
         self.save_hyperparameters()
 
-        self._parameters = parameters
+        self._data_parameters = parameters
 
         metadata = self.backbones.get(backbone, with_metadata=True)
         adapter = metadata["metadata"]["adapter"].from_task(
@@ -96,6 +100,39 @@ class TabularClassifier(ClassificationAdapterTask):
             labels=labels,
         )
 
+    @property
+    def data_parameters(self) -> Dict[str, Any]:
+        """Get the parameters computed from the training data used to create this
+        :class:`~flash.tabular.classification.TabularClassifier`. Use these parameters to load data for
+        evaluation / prediction.
+
+        Examples
+        ________
+
+        .. doctest::
+
+            >>> import flash
+            >>> from flash.core.data.utils import download_data
+            >>> from flash.tabular import TabularClassificationData, TabularClassifier
+            >>> download_data("https://pl-flash-data.s3.amazonaws.com/titanic.zip", "./data")
+            >>> model = TabularClassifier.load_from_checkpoint(
+            ...     "https://flash-weights.s3.amazonaws.com/0.7.0/tabular_classification_model.pt"
+            ... )
+            >>> datamodule = TabularClassificationData.from_csv(
+            ...     predict_file="data/titanic/predict.csv",
+            ...     parameters=model.data_parameters,
+            ...     batch_size=8,
+            ... )
+            >>> trainer = flash.Trainer()
+            >>> trainer.predict(
+            ...     model,
+            ...     datamodule=datamodule,
+            ...     output="classes",
+            ... )  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+            Predicting...
+        """
+        return self._data_parameters
+
     @staticmethod
     def _ci_benchmark_fn(history: List[Dict[str, Any]]):
         """This function is used only for debugging usage with CI."""
@@ -125,7 +162,7 @@ class TabularClassifier(ClassificationAdapterTask):
         output: Optional[Union[str, Output]] = None,
         parameters: Optional[Dict[str, Any]] = None,
     ) -> Composition:
-        parameters = parameters or self._parameters
+        parameters = parameters or self._data_parameters
         return super().serve(
             host, port, sanity_check, partial(input_cls, parameters=parameters), transform, transform_kwargs, output
         )
