@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Collection, Dict, List, Optional, Sequence, Type, Union
+from typing import Any, Callable, Collection, Dict, List, Optional, Sequence, Tuple, Type
 
 import numpy as np
 import torch
@@ -98,20 +98,17 @@ class TemplateInputTransform(InputTransform):
     """An example :class:`~flash.core.data.io.input_transform.InputTransform`."""
 
     @staticmethod
-    def input_to_tensor(input: np.ndarray):
-        """Transform which creates a tensor from the given numpy ``ndarray`` and converts it to ``float``"""
-        return torch.from_numpy(input).float()
+    def to_tensor(sample: Dict[str, Any]):
+        """Transform which converts the sample to a tensor."""
+        sample[DataKeys.INPUT] = torch.from_numpy(sample[DataKeys.INPUT]).float()
 
-    @staticmethod
-    def target_to_tensor(target: Union[int, List[int]]):
-        """Transform which creates a tensor from the given target and casts it to ``long``"""
-        return torch.as_tensor(target).long()
+        if DataKeys.TARGET in sample:
+            sample[DataKeys.TARGET] = torch.as_tensor(sample[DataKeys.TARGET]).long()
 
-    def input_per_sample_transform(self) -> Callable:
-        return self.input_to_tensor
+        return sample
 
-    def target_per_sample_transform(self) -> Callable:
-        return self.target_to_tensor
+    def per_sample_transform(self) -> Callable:
+        return self.to_tensor
 
 
 class TemplateData(DataModule):
@@ -134,11 +131,8 @@ class TemplateData(DataModule):
         test_data: Optional[Collection[np.ndarray]] = None,
         test_targets: Optional[Sequence[Any]] = None,
         predict_data: Optional[Collection[np.ndarray]] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
         input_cls: Type[Input] = TemplateNumpyClassificationInput,
+        transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
         transform_kwargs: Optional[Dict] = None,
         **data_module_kwargs: Any,
     ) -> "TemplateData":
@@ -153,46 +147,28 @@ class TemplateData(DataModule):
             test_data: The numpy ``Array`` containing the test data.
             test_targets: The sequence of test targets.
             predict_data: The numpy ``Array`` containing the predict data.
-            train_transform: The dictionary of transforms to use during training which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            val_transform: The dictionary of transforms to use during validation which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            test_transform: The dictionary of transforms to use during testing which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            predict_transform: The dictionary of transforms to use during predicting which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
+            input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
+            transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
+            data_module_kwargs: Additional keyword arguments to provide to the
+              :class:`~flash.core.data.data_module.DataModule` constructor.
 
         Returns:
             The constructed data module.
         """
 
-        ds_kw = dict(
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
-        )
+        ds_kw = dict()
 
-        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_data, train_targets, **ds_kw)
         target_formatter = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(
-                RunningStage.VALIDATING,
-                val_data,
-                val_targets,
-                transform=val_transform,
-                target_formatter=target_formatter,
-                **ds_kw,
-            ),
-            input_cls(
-                RunningStage.TESTING,
-                test_data,
-                test_targets,
-                transform=test_transform,
-                target_formatter=target_formatter,
-                **ds_kw,
-            ),
-            input_cls(RunningStage.PREDICTING, predict_data, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_data, val_targets, target_formatter=target_formatter, **ds_kw),
+            input_cls(RunningStage.TESTING, test_data, test_targets, target_formatter=target_formatter, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_data, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -203,11 +179,8 @@ class TemplateData(DataModule):
         val_bunch: Optional[Bunch] = None,
         test_bunch: Optional[Bunch] = None,
         predict_bunch: Optional[Bunch] = None,
-        train_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        val_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        test_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
-        predict_transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
         input_cls: Type[Input] = TemplateSKLearnClassificationInput,
+        transform: INPUT_TRANSFORM_TYPE = TemplateInputTransform,
         transform_kwargs: Optional[Dict] = None,
         **data_module_kwargs: Any,
     ) -> "TemplateData":
@@ -219,43 +192,27 @@ class TemplateData(DataModule):
             val_bunch: The scikit-learn ``Bunch`` containing the validation data.
             test_bunch: The scikit-learn ``Bunch`` containing the test data.
             predict_bunch: The scikit-learn ``Bunch`` containing the predict data.
-            train_transform: The dictionary of transforms to use during training which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            val_transform: The dictionary of transforms to use during validation which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            test_transform: The dictionary of transforms to use during testing which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
-            predict_transform: The dictionary of transforms to use during predicting which maps
-                :class:`~flash.core.data.io.input_transform.InputTransform` hook names to callable transforms.
+            input_cls: The :class:`~flash.core.data.io.input.Input` type to use for loading the data.
+            transform: The :class:`~flash.core.data.io.input_transform.InputTransform` type to use.
+            transform_kwargs: Dict of keyword arguments to be provided when instantiating the transforms.
+            data_module_kwargs: Additional keyword arguments to provide to the
+              :class:`~flash.core.data.data_module.DataModule` constructor.
 
         Returns:
             The constructed data module.
         """
-        ds_kw = dict(
-            transform_kwargs=transform_kwargs,
-            input_transforms_registry=cls.input_transforms_registry,
-        )
+        ds_kw = dict()
 
-        train_input = input_cls(RunningStage.TRAINING, train_bunch, transform=train_transform, **ds_kw)
+        train_input = input_cls(RunningStage.TRAINING, train_bunch, **ds_kw)
         target_formatter = getattr(train_input, "target_formatter", None)
 
         return cls(
             train_input,
-            input_cls(
-                RunningStage.VALIDATING,
-                val_bunch,
-                transform=val_transform,
-                target_formatter=target_formatter,
-                **ds_kw,
-            ),
-            input_cls(
-                RunningStage.TESTING,
-                test_bunch,
-                transform=test_transform,
-                target_formatter=target_formatter,
-                **ds_kw,
-            ),
-            input_cls(RunningStage.PREDICTING, predict_bunch, transform=predict_transform, **ds_kw),
+            input_cls(RunningStage.VALIDATING, val_bunch, target_formatter=target_formatter, **ds_kw),
+            input_cls(RunningStage.TESTING, test_bunch, target_formatter=target_formatter, **ds_kw),
+            input_cls(RunningStage.PREDICTING, predict_bunch, **ds_kw),
+            transform=transform,
+            transform_kwargs=transform_kwargs,
             **data_module_kwargs,
         )
 
@@ -283,8 +240,20 @@ class TemplateVisualization(BaseVisualization):
     If you want to provide a visualization with your task, you can override these hooks.
     """
 
-    def show_load_sample(self, samples: List[Any], running_stage: RunningStage):
+    def show_load_sample(
+        self,
+        samples: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ):
         print(samples)
 
-    def show_per_sample_transform(self, samples: List[Any], running_stage: RunningStage):
+    def show_per_sample_transform(
+        self,
+        samples: List[Any],
+        running_stage: RunningStage,
+        limit_nb_samples: int = None,
+        figsize: Tuple[int, int] = (6.4, 4.8),
+    ):
         print(samples)
